cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "nb_NO",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 CPU configuration": [
  null,
  "$0 CPU konfigurasjon"
 ],
 "$0 Network": [
  "$0 Networks",
  "$0 Nettverk",
  "$0 Nettverk"
 ],
 "$0 Storage pool": [
  "$0 Storage pools",
  "$0 lagrings-pool",
  "$0 lagrings-pooler"
 ],
 "$0 day": [
  "$0 days",
  "$0 dag",
  "$0 dager"
 ],
 "$0 hour": [
  "$0 hours",
  "$0 time",
  "$0 timer"
 ],
 "$0 is available for most operating systems. To install it, search for it in GNOME Software or run the following:": [
  null,
  "$0 er tilgjengelig for de fleste operativsystemer. For å installere det, søk etter det i GNOME-programvaren eller kjør følgende:"
 ],
 "$0 is not available from any repository.": [
  null,
  ""
 ],
 "$0 memory adjustment": [
  null,
  "$0 minnejustering"
 ],
 "$0 minute": [
  "$0 minutes",
  "$0 minutt",
  "$0 minutter"
 ],
 "$0 month": [
  "$0 months",
  "$0 måned",
  "$0 måneder"
 ],
 "$0 network": [
  null,
  "$0 nettverk"
 ],
 "$0 vCPU": [
  "$0 vCPUs",
  "$0 vCPU",
  "$0 vCPUer"
 ],
 "$0 vCPU details": [
  null,
  "$0 vCPU detaljer"
 ],
 "$0 virtual network interface settings": [
  null,
  ""
 ],
 "$0 week": [
  "$0 weeks",
  "$0 uke",
  "$0 uker"
 ],
 "$0 will be installed.": [
  null,
  "$0 vil bli installert."
 ],
 "$0 year": [
  "$0 years",
  "$0 år",
  "$0 år"
 ],
 "1 day": [
  null,
  "1 dag"
 ],
 "1 hour": [
  null,
  "1 time"
 ],
 "1 minute": [
  null,
  "1 minutt"
 ],
 "1 week": [
  null,
  "1 uke"
 ],
 "20 minutes": [
  null,
  "20 minutter"
 ],
 "40 minutes": [
  null,
  "40 minutter"
 ],
 "5 minutes": [
  null,
  "5 minutter"
 ],
 "6 hours": [
  null,
  "6 timer"
 ],
 "60 minutes": [
  null,
  "60 minutter"
 ],
 "Absent": [
  null,
  "Fraværende"
 ],
 "Access": [
  null,
  "Tilgang"
 ],
 "Activate": [
  null,
  "Aktiver"
 ],
 "Activate the storage pool to administer volumes": [
  null,
  "Aktiver lagrings-poolen for å administrere volumer"
 ],
 "Add": [
  null,
  "Legg til"
 ],
 "Add disk": [
  null,
  "Legg til disk"
 ],
 "Add network interface": [
  null,
  "Legg til nettverksgrensesnitt"
 ],
 "Add virtual network interface": [
  null,
  "Legg til virtuelt nettverksgrensesnitt"
 ],
 "Additional": [
  null,
  ""
 ],
 "Additional packages:": [
  null,
  "Ekstra pakker:"
 ],
 "Address": [
  null,
  "Adresse"
 ],
 "Address not within subnet": [
  null,
  "Adressen ligger ikke i subnettet"
 ],
 "Advanced TCA": [
  null,
  "Avansert TCA"
 ],
 "After deleting the snapshot, all its captured content will be lost.": [
  null,
  "Etter å ha slettet øyeblikksbildet, vil alt innfanget innhold gå tapt."
 ],
 "All": [
  null,
  "Alle"
 ],
 "All logs": [
  null,
  "Alle logger"
 ],
 "All-in-one": [
  null,
  ""
 ],
 "Always attach": [
  null,
  ""
 ],
 "Ansible": [
  null,
  "Ansible"
 ],
 "Ansible roles documentation": [
  null,
  "Ansible roller dokumentasjon"
 ],
 "Apply": [
  null,
  "Bruk"
 ],
 "Attaching it will make this disk shareable for every VM using it.": [
  null,
  ""
 ],
 "Automatic": [
  null,
  "Automatisk"
 ],
 "Automatically start libvirt on boot": [
  null,
  "Start libvirt automatisk ved oppstart"
 ],
 "Automatically using NTP": [
  null,
  "Automatisk med bruk av NTP"
 ],
 "Automatically using specific NTP servers": [
  null,
  ""
 ],
 "Automation script": [
  null,
  "Automatiseringsskript"
 ],
 "Autostart": [
  null,
  "Autostart"
 ],
 "Blade": [
  null,
  ""
 ],
 "Blade enclosure": [
  null,
  ""
 ],
 "Blocked": [
  null,
  "Blokkert"
 ],
 "Boot order": [
  null,
  "Oppstartsrekkefølge"
 ],
 "Boot order settings could not be saved": [
  null,
  "Innstillinger for oppstartsrekkefølge kunne ikke lagres"
 ],
 "Bus": [
  null,
  "Buss"
 ],
 "Bus expansion chassis": [
  null,
  ""
 ],
 "CD/DVD disc": [
  null,
  "CD/DVD disk"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU configuration could not be saved": [
  null,
  "CPU-konfigurasjon kunne ikke lagres"
 ],
 "CPU type": [
  null,
  "CPU type"
 ],
 "Cache": [
  null,
  "Hurtigbuffer"
 ],
 "Cancel": [
  null,
  "Avbryt"
 ],
 "Cannot schedule event in the past": [
  null,
  "Kan ikke tidsplanlegge hendelse i fortiden"
 ],
 "Capacity": [
  null,
  "Kapasitet"
 ],
 "Change": [
  null,
  "Endre"
 ],
 "Change firmware": [
  null,
  "Bytt fastvare"
 ],
 "Change system time": [
  null,
  "Endre systemtid"
 ],
 "Changes will take effect after shutting down the VM": [
  null,
  "Endringer vil tre i kraft etter at den virtuelle maskinen er slått av"
 ],
 "Checking installed software": [
  null,
  "Kontrollerer installert programvare"
 ],
 "Choose an operating system": [
  null,
  "Velg et operativsystem"
 ],
 "Clicking \"Launch remote viewer\" will download a .vv file and launch $0.": [
  null,
  "Ved å klikke på \"Start ekstern visning\" lastes en .vv-fil ned og $0 startes."
 ],
 "Clone": [
  null,
  "Klon"
 ],
 "Close": [
  null,
  "Lukk"
 ],
 "Cloud base image": [
  null,
  ""
 ],
 "Cloud init parameters": [
  null,
  ""
 ],
 "Compact PCI": [
  null,
  ""
 ],
 "Confirm this action": [
  null,
  "Bekreft denne handlingen"
 ],
 "Connect": [
  null,
  "Koble til"
 ],
 "Connect with any viewer application for following protocols": [
  null,
  "Koble til et hvilket som helst visningsprogram for følgende protokoller"
 ],
 "Connecting to virtualization service": [
  null,
  "Koble til virtualiseringstjeneste"
 ],
 "Connection": [
  null,
  "Tilkobling"
 ],
 "Console": [
  null,
  "Konsoll"
 ],
 "Convertible": [
  null,
  ""
 ],
 "Copy": [
  null,
  "Kopier"
 ],
 "Copy to clipboard": [
  null,
  "Kopier til utklippstavle"
 ],
 "Cores per socket": [
  null,
  "Kjerner per sokkel"
 ],
 "Could not revert to snapshot": [
  null,
  "Kunne ikke gå tilbake til øyeblikksbildet"
 ],
 "Crashed": [
  null,
  "Krasjet"
 ],
 "Create": [
  null,
  "Opprett"
 ],
 "Create VM": [
  null,
  "Opprett VM"
 ],
 "Create a clone VM based on $0": [
  null,
  "Opprett en klone-VM basert på $0"
 ],
 "Create new": [
  null,
  "Opprett ny"
 ],
 "Create new task file with this content.": [
  null,
  "Opprett ny oppgavefil med dette innholdet."
 ],
 "Create new virtual machine": [
  null,
  "Opprett ny virtuell maskin"
 ],
 "Create new volume": [
  null,
  "Opprett nytt volum"
 ],
 "Create snapshot": [
  null,
  "Opprett øyeblikksbilde"
 ],
 "Create storage pool": [
  null,
  "Opprett lagrings-pool"
 ],
 "Create storage volume": [
  null,
  "Opprett lagringsvolum"
 ],
 "Create virtual network": [
  null,
  "Opprett virtuelt nettverk"
 ],
 "Create volume": [
  null,
  "Opprett volum"
 ],
 "Creating VM": [
  null,
  "Oppretter VM"
 ],
 "Creating VM installation": [
  null,
  "Oppretter VM-installasjon"
 ],
 "Creation of VM $0 failed": [
  null,
  "Opprettelsen av VM $0 feilet"
 ],
 "Creation time": [
  null,
  ""
 ],
 "Ctrl+Alt+$0": [
  null,
  "Ctrl+Alt+$0"
 ],
 "Ctrl+Insert": [
  null,
  "Ctrl+Insert"
 ],
 "Current": [
  null,
  "Gjeldende"
 ],
 "Current allocation": [
  null,
  "Gjeldende tildeling"
 ],
 "Custom firmware: $0": [
  null,
  ""
 ],
 "Custom path": [
  null,
  ""
 ],
 "DHCP range": [
  null,
  "DHCP-område"
 ],
 "Deactivate": [
  null,
  "Deaktiver"
 ],
 "Delay": [
  null,
  "Forsinkelse"
 ],
 "Delete": [
  null,
  "Slett"
 ],
 "Delete $0 volume": [
  "Delete $0 volumes",
  "Slett $0 volum",
  "Slett $0 volumer"
 ],
 "Delete associated storage files:": [
  null,
  "Slett tilknyttede lagringsfiler:"
 ],
 "Delete content": [
  null,
  "Slett innhold"
 ],
 "Delete storage pool $0": [
  null,
  "Slett lagrings-pool $0"
 ],
 "Delete the volumes inside this pool": [
  null,
  "Slett volumene i denne poolen"
 ],
 "Deleting an inactive storage pool will only undefine the pool. Its content will not be deleted.": [
  null,
  "Slette en inaktiv lagrings-pool vil bare avdefinere poolen. Innholdet vil ikke bli slettet."
 ],
 "Description": [
  null,
  "Beskrivelse"
 ],
 "Desktop": [
  null,
  ""
 ],
 "Desktop viewer": [
  null,
  ""
 ],
 "Detach the disks using this pool from any VMs before attempting deletion.": [
  null,
  "Koble diskene som bruker denne poolen fra alle virtuelle maskiner før du prøver å slette."
 ],
 "Detachable": [
  null,
  ""
 ],
 "Device": [
  null,
  "Enhet"
 ],
 "Devices": [
  null,
  "Enheter"
 ],
 "Disconnect": [
  null,
  "Koble fra"
 ],
 "Disconnected from serial console. Click the connect button.": [
  null,
  "Koblet fra seriekonsollet. Klikk på tilkoblingsknappen."
 ],
 "Disk $0 fail to get detached from VM $1": [
  null,
  "Disk $0 kan ikke løsnes fra VM $1"
 ],
 "Disk failed to be attached": [
  null,
  "Disken kunne ikke kobles til"
 ],
 "Disk failed to be created": [
  null,
  "Disken ble ikke opprettet"
 ],
 "Disk image file": [
  null,
  ""
 ],
 "Disk settings could not be saved": [
  null,
  "Diskinnstillinger kunne ikke lagres"
 ],
 "Disk-only snapshot": [
  null,
  ""
 ],
 "Disks": [
  null,
  "Disker"
 ],
 "Docking station": [
  null,
  ""
 ],
 "Domain has crashed": [
  null,
  "Domenet har krasjet"
 ],
 "Domain is blocked on resource": [
  null,
  "Domenet er blokkert på ressursen"
 ],
 "Download an OS": [
  null,
  "Last ned et OS"
 ],
 "Downloading $0": [
  null,
  "Laster ned $0"
 ],
 "Dual rank": [
  null,
  ""
 ],
 "Dying": [
  null,
  ""
 ],
 "Edit": [
  null,
  "Rediger"
 ],
 "Edit $0 attributes": [
  null,
  "Rediger $0 attributter"
 ],
 "Embedded PC": [
  null,
  ""
 ],
 "Emulated machine": [
  null,
  "Emulert maskin"
 ],
 "End": [
  null,
  ""
 ],
 "End should not be empty": [
  null,
  ""
 ],
 "Error message": [
  null,
  "Feilmelding"
 ],
 "Error running semanage to discover system modifications": [
  null,
  "Feil ved kjøring av semanage for å oppdage systemendringer"
 ],
 "Excellent password": [
  null,
  "Utmerket passord"
 ],
 "Existing disk image on host's file system": [
  null,
  "Eksisterende diskbilde på vertens filsystem"
 ],
 "Expand": [
  null,
  "Utvid"
 ],
 "Expansion chassis": [
  null,
  ""
 ],
 "Failed": [
  null,
  "Feilet"
 ],
 "Failed to change firmware": [
  null,
  "Kunne ikke endre fastvare"
 ],
 "Failed to change password": [
  null,
  "Kunne ikke endre passord"
 ],
 "Failed to clone VM $0": [
  null,
  "Kunne ikke klone VM $0"
 ],
 "Failed to fetch the IP addresses of the interfaces present in $0": [
  null,
  "Kunne ikke hente IP-adressene til grensesnittene i $0"
 ],
 "Failed to send key Ctrl+Alt+$0 to VM $1": [
  null,
  "Kunne ikke sende tast Ctrl+Alt+$0 til VM $1"
 ],
 "Fewer than the maximum number of virtual CPUs should be enabled.": [
  null,
  ""
 ],
 "File": [
  null,
  "Fil"
 ],
 "Filesystem directory": [
  null,
  "Filsystem katalog"
 ],
 "Filter by name": [
  null,
  "Filtrer etter navn"
 ],
 "Firmware": [
  null,
  "Fastvare"
 ],
 "Force reboot": [
  null,
  "Tving omstart"
 ],
 "Force shut down": [
  null,
  "Tving nedstenging"
 ],
 "Format": [
  null,
  "Format"
 ],
 "Forward mode": [
  null,
  "Videresendingsmodus"
 ],
 "Forwarding mode": [
  null,
  "Videresendingsmodus"
 ],
 "General": [
  null,
  "Generelt"
 ],
 "Generate automatically": [
  null,
  "Generer automatisk"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Go to VMs list": [
  null,
  "Gå til VM-listen"
 ],
 "Go to now": [
  null,
  "Gå til nå"
 ],
 "Handheld": [
  null,
  "Håndholdt"
 ],
 "Hide additional options": [
  null,
  ""
 ],
 "Host": [
  null,
  "Vert"
 ],
 "Host device": [
  null,
  ""
 ],
 "Host name": [
  null,
  "Vertsnavn"
 ],
 "Host should not be empty": [
  null,
  "Vert kan ikke være tom"
 ],
 "Hours must be a number between 0 and 23": [
  null,
  "Timer må være et tall mellom 0 og 23"
 ],
 "Hypervisor details": [
  null,
  "Hypervisor detaljer"
 ],
 "ID": [
  null,
  "ID"
 ],
 "IP address": [
  null,
  "IP adresse"
 ],
 "IP configuration": [
  null,
  "IP-konfigurasjon"
 ],
 "IPv4 address": [
  null,
  "IPv4- adresse"
 ],
 "IPv4 and IPv6": [
  null,
  "IPv4 og IPv6"
 ],
 "IPv4 network": [
  null,
  "IPv4-nettverk"
 ],
 "IPv4 network should not be empty": [
  null,
  "IPv6-nettverk kan ikke være tomt"
 ],
 "IPv4 only": [
  null,
  "Bare IPv4"
 ],
 "IPv6 address": [
  null,
  "IPv6-adresse"
 ],
 "IPv6 network": [
  null,
  "IPv6-nettverk"
 ],
 "IPv6 network should not be empty": [
  null,
  "IPv6-nettverk kan ikke være tomt"
 ],
 "IPv6 only": [
  null,
  "Bare IPv6"
 ],
 "Idle": [
  null,
  "Ledig"
 ],
 "Immediately start VM": [
  null,
  "Start VM umiddelbart"
 ],
 "Import": [
  null,
  "Importer"
 ],
 "Import VM": [
  null,
  "Importer VM"
 ],
 "Import a virtual machine": [
  null,
  "Importer en virtuell maskin"
 ],
 "In most configurations, macvtap does not work for host to guest network communication.": [
  null,
  ""
 ],
 "Initiator": [
  null,
  "Initiator"
 ],
 "Initiator IQN should not be empty": [
  null,
  "Initiator IQN kan ikke være tom"
 ],
 "Install": [
  null,
  "Installer"
 ],
 "Install software": [
  null,
  "Installer programvare"
 ],
 "Installation source": [
  null,
  "Installasjonskilde"
 ],
 "Installation source must not be empty": [
  null,
  "Installasjonskilde kan ikke være tom"
 ],
 "Installation type": [
  null,
  "Installasjonstype"
 ],
 "Installing $0": [
  null,
  "Installerer $0"
 ],
 "Interface type": [
  null,
  "Grensesnitt type"
 ],
 "Invalid IPv4 address": [
  null,
  "Ugyldig IPv4-adresse"
 ],
 "Invalid IPv4 mask or prefix length": [
  null,
  "Ugyldig IPv4-maske eller prefikslengde"
 ],
 "Invalid IPv6 address": [
  null,
  "Ugyldig IPv6-adresse"
 ],
 "Invalid IPv6 prefix": [
  null,
  "Ugyldig IPv6-prefiks"
 ],
 "Invalid date format": [
  null,
  "Ugyldig datoformat"
 ],
 "Invalid date format and invalid time format": [
  null,
  "Ugyldig datoformat og ugyldig tidsformat"
 ],
 "Invalid file permissions": [
  null,
  "Ugyldige filtillatelser"
 ],
 "Invalid filename": [
  null,
  "Ugyldig filnavn"
 ],
 "Invalid time format": [
  null,
  "Ugyldig tidsformat"
 ],
 "Invalid timezone": [
  null,
  "Ugyldig tidssone"
 ],
 "IoT gateway": [
  null,
  "IoT-gateway"
 ],
 "Isolated network": [
  null,
  "Isolert nettverk"
 ],
 "LVM volume group": [
  null,
  "LVM volumgruppe"
 ],
 "Laptop": [
  null,
  ""
 ],
 "Launch remote viewer": [
  null,
  ""
 ],
 "Learn more": [
  null,
  "Lær mer"
 ],
 "Leave the password blank if you do not wish to have a root account created": [
  null,
  "La passordet være tomt hvis du ikke ønsker å opprette en rotkonto"
 ],
 "Leave the password blank if you do not wish to have a user account created": [
  null,
  "La passordet være tomt hvis du ikke ønsker å opprette en brukerkonto"
 ],
 "Libvirt did not detect any UEFI/OVMF firmware image installed on the host": [
  null,
  "Libvirt oppdaget ikke noe UEFI/OVMF firmwarebilde installert på verten"
 ],
 "Libvirt or hypervisor does not support UEFI": [
  null,
  "Libvirt eller hypervisor støtter ikke UEFI"
 ],
 "Loading resources": [
  null,
  "Laster ressurser"
 ],
 "Loading system modifications...": [
  null,
  "Laster inn systemendringer ..."
 ],
 "Loading...": [
  null,
  "Laster..."
 ],
 "Local install media (ISO image or distro install tree)": [
  null,
  ""
 ],
 "Log messages": [
  null,
  "Logg meldinger"
 ],
 "Low profile desktop": [
  null,
  ""
 ],
 "Lunch box": [
  null,
  "Lunsjboks"
 ],
 "MAC": [
  null,
  "MAC"
 ],
 "MAC address": [
  null,
  "MAC-adresse"
 ],
 "Machine must be shut off before changing bus type": [
  null,
  "Maskinen må være stengt før du bytter busstype"
 ],
 "Machine must be shut off before changing cache mode": [
  null,
  "Maskinen må være slått av før du bytter hurtigbuffermodus"
 ],
 "Main server chassis": [
  null,
  ""
 ],
 "Managing virtual machines": [
  null,
  "Administrere virtuelle maskiner"
 ],
 "Manual connection": [
  null,
  "Manuell tilkobling"
 ],
 "Manually": [
  null,
  "Manuelt"
 ],
 "Mask or prefix length": [
  null,
  "Maske eller prefikslengde"
 ],
 "Mask or prefix length should not be empty": [
  null,
  "Masken eller prefikslengden kan ikke være tom"
 ],
 "Maximum allocation": [
  null,
  ""
 ],
 "Maximum memory could not be saved": [
  null,
  ""
 ],
 "Maximum number of virtual CPUs allocated for the guest OS": [
  null,
  "Maksimalt antall virtuelle CPUer som er tildelt for gjeste-OS"
 ],
 "Maximum number of virtual CPUs allocated for the guest OS, which must be between 1 and $0": [
  null,
  "Maksimalt antall virtuelle CPUer som er tildelt for gjeste-OS, som må være mellom 1 og $0"
 ],
 "Maximum transmission unit": [
  null,
  "Maksimal overføringsenhet"
 ],
 "Memory": [
  null,
  "Minne"
 ],
 "Memory could not be saved": [
  null,
  ""
 ],
 "Memory must not be 0": [
  null,
  ""
 ],
 "Message to logged in users": [
  null,
  "Melding til innloggede brukere"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Mini PC": [
  null,
  "Mini PC"
 ],
 "Mini tower": [
  null,
  ""
 ],
 "Minutes must be a number between 0 and 59": [
  null,
  "Minutter må være et tall mellom 0 og 59"
 ],
 "Mode": [
  null,
  "Modus"
 ],
 "Model": [
  null,
  "Modell"
 ],
 "Model type": [
  null,
  "Modelltype"
 ],
 "Multi-system chassis": [
  null,
  ""
 ],
 "NAT to $0": [
  null,
  "NAT til $0"
 ],
 "NIC $0 of VM $1 failed to change state": [
  null,
  "NIC $0 for VM $1 kunne ikke endre tilstand"
 ],
 "NTP server": [
  null,
  "NTP Server"
 ],
 "Name": [
  null,
  "Navn"
 ],
 "Name contains invalid characters": [
  null,
  "Navnet inneholder ugyldige tegn"
 ],
 "Name must not be empty": [
  null,
  "Navnet kan ikke være tomt"
 ],
 "Name should not be empty": [
  null,
  "Navnet bør ikke være tomt"
 ],
 "Name: ": [
  null,
  "Navn: "
 ],
 "Need at least one NTP server": [
  null,
  "Trenger minst en NTP-server"
 ],
 "Netmask": [
  null,
  "Nettmaske"
 ],
 "Network $0 failed to get activated": [
  null,
  "Nettverk $0 kunne ikke aktiveres"
 ],
 "Network $0 failed to get deactivated": [
  null,
  "Nettverk $0 kunne ikke deaktiveres"
 ],
 "Network boot (PXE)": [
  null,
  "Nettverksstart (PXE)"
 ],
 "Network file system": [
  null,
  "Nettverksfilsystem"
 ],
 "Network interface settings could not be saved": [
  null,
  "Innstillinger for nettverksgrensesnitt kunne ikke lagres"
 ],
 "Network selection does not support PXE.": [
  null,
  "Nettverksvalg støtter ikke PXE."
 ],
 "Networks": [
  null,
  "Nettverk"
 ],
 "New password was not accepted": [
  null,
  "Nytt passord ble ikke godtatt"
 ],
 "New volume name": [
  null,
  "Nytt volumnavn"
 ],
 "No VM is running or defined on this host": [
  null,
  "Ingen VM kjører eller er definert på denne verten"
 ],
 "No boot device found": [
  null,
  ""
 ],
 "No connection available": [
  null,
  "Ingen tilkobling tilgjengelig"
 ],
 "No delay": [
  null,
  "Ingen forsinkelse"
 ],
 "No description": [
  null,
  "Ingen beskrivelse"
 ],
 "No disks defined for this VM": [
  null,
  "Ingen disker definert for denne VMen"
 ],
 "No network devices": [
  null,
  "Ingen nettverksenheter"
 ],
 "No network interfaces defined for this VM": [
  null,
  "Ingen nettverksgrensesnitt definert for denne VMen"
 ],
 "No network is defined on this host": [
  null,
  ""
 ],
 "No networks available": [
  null,
  "Ingen nettverk tilgjengelig"
 ],
 "No parent": [
  null,
  ""
 ],
 "No snapshots defined for this VM": [
  null,
  ""
 ],
 "No state": [
  null,
  "Ingen tilstand"
 ],
 "No storage": [
  null,
  "Ingen lagring"
 ],
 "No storage pool is defined on this host": [
  null,
  "Ingen lagrings-pool er definert på denne verten"
 ],
 "No storage pools available": [
  null,
  "Ingen lagrings-pooler tilgjengelig"
 ],
 "No storage volumes defined for this storage pool": [
  null,
  "Ingen lagringsvolumer definert for denne lagrings-poolen"
 ],
 "No such file or directory": [
  null,
  "Ingen slik fil eller katalog"
 ],
 "No system modifications": [
  null,
  "Ingen systemendringer"
 ],
 "No virtual networks": [
  null,
  "Ingen virtuelle nettverk"
 ],
 "Non-persistent network cannot be deleted. It ceases to exists when it's deactivated.": [
  null,
  ""
 ],
 "Non-persistent storage pool cannot be deleted. It ceases to exists when it's deactivated.": [
  null,
  ""
 ],
 "None": [
  null,
  "Ingen"
 ],
 "None (isolated network)": [
  null,
  "Ingen (isolert nettverk)"
 ],
 "Not a valid private key": [
  null,
  "Ikke en gyldig privat nøkkel"
 ],
 "Not synchronized": [
  null,
  "Ikke synkronisert"
 ],
 "Notebook": [
  null,
  ""
 ],
 "Ok": [
  null,
  "Ok"
 ],
 "Old password not accepted": [
  null,
  "Gammelt passord aksepteres ikke"
 ],
 "One or more selected volumes are used by domains. Detach the disks first to allow volume deletion.": [
  null,
  ""
 ],
 "Only editable when the guest is shut off": [
  null,
  "Bare redigerbar når gjesten er slått av"
 ],
 "Open": [
  null,
  ""
 ],
 "Operating system": [
  null,
  "Operativsystem"
 ],
 "Operation is in progress": [
  null,
  ""
 ],
 "Other": [
  null,
  "Annen"
 ],
 "Overview": [
  null,
  "Oversikt"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit krasjet"
 ],
 "Parent snapshot": [
  null,
  ""
 ],
 "Password is not acceptable": [
  null,
  "Passord er ikke akseptabelt"
 ],
 "Password is too weak": [
  null,
  "Passordet er for svakt"
 ],
 "Password not accepted": [
  null,
  "Passord ikke akseptert"
 ],
 "Paste": [
  null,
  "Lim inn"
 ],
 "Path": [
  null,
  "Sti"
 ],
 "Path on host's filesystem": [
  null,
  "Sti på vertens filsystem"
 ],
 "Path to ISO file on host's file system": [
  null,
  "Sti til ISO-fil på vertens filsystem"
 ],
 "Path to file": [
  null,
  "Sti til fil"
 ],
 "Path to file on host's file system": [
  null,
  "Sti til fil på vertens filsystem"
 ],
 "Pause": [
  null,
  "Pause"
 ],
 "Paused": [
  null,
  "Pauset"
 ],
 "Peripheral chassis": [
  null,
  ""
 ],
 "Persistence": [
  null,
  ""
 ],
 "Persistent": [
  null,
  "Vedvarende"
 ],
 "Physical disk device": [
  null,
  "Fysisk disk-enhet"
 ],
 "Physical disk device on host": [
  null,
  "Fysisk disk-enhet på vert"
 ],
 "Pick date": [
  null,
  "Velg dato"
 ],
 "Pizza box": [
  null,
  ""
 ],
 "Please choose a storage pool": [
  null,
  ""
 ],
 "Please choose a volume": [
  null,
  "Velg et volum"
 ],
 "Please enter new volume name": [
  null,
  "Vennligst skriv inn nytt volumnavn"
 ],
 "Please start the virtual machine to access its console.": [
  null,
  "Start den virtuelle maskinen for å få tilgang til konsollen."
 ],
 "Plug": [
  null,
  ""
 ],
 "Pool": [
  null,
  ""
 ],
 "Pool needs to be active to create volume": [
  null,
  "Pool må være aktiv for å opprette volum"
 ],
 "Pool type doesn't support volume creation": [
  null,
  "Bassengtype støtter ikke volumoppretting"
 ],
 "Pool's volumes are used by VMs ": [
  null,
  ""
 ],
 "Port": [
  null,
  "Port"
 ],
 "Portable": [
  null,
  ""
 ],
 "Preferred number of sockets to expose to the guest.": [
  null,
  ""
 ],
 "Prefix": [
  null,
  "Prefiks"
 ],
 "Prefix length": [
  null,
  "Prefikslengde"
 ],
 "Prefix length should not be empty": [
  null,
  "Prefikslengden skal ikke være tom"
 ],
 "Present": [
  null,
  "Til stede"
 ],
 "Previously taken snapshots allow you to revert to an earlier state if something goes wrong": [
  null,
  ""
 ],
 "Private": [
  null,
  "Privat"
 ],
 "Product": [
  null,
  "Produkt"
 ],
 "Profile": [
  null,
  "Profil"
 ],
 "Prompting via ssh-add timed out": [
  null,
  ""
 ],
 "Prompting via ssh-keygen timed out": [
  null,
  ""
 ],
 "Protocol": [
  null,
  "Protokoll"
 ],
 "RAID chassis": [
  null,
  "RAID chassis"
 ],
 "Rack mount chassis": [
  null,
  ""
 ],
 "Read-only": [
  null,
  ""
 ],
 "Reboot": [
  null,
  "Omstart"
 ],
 "Remote URL": [
  null,
  ""
 ],
 "Remote viewer details": [
  null,
  ""
 ],
 "Removals:": [
  null,
  ""
 ],
 "Remove": [
  null,
  "Fjern"
 ],
 "Removing $0": [
  null,
  "Fjerner $0"
 ],
 "Resume": [
  null,
  "Gjenoppta"
 ],
 "Revert": [
  null,
  ""
 ],
 "Revert to snapshot $0": [
  null,
  ""
 ],
 "Reverting to this snapshot will take the VM back to the time of the snapshot and the current state will be lost, along with any data not captured in a snapshot": [
  null,
  "Å gå tilbake til dette øyeblikksbildet vil føre VM tilbake til tidspunktet for øyeblikksbildet, og den nåværende tilstanden vil gå tapt, sammen med data som ikke blir tatt i et øyeblikksbilde"
 ],
 "Root password": [
  null,
  "Root passord"
 ],
 "Route to $0": [
  null,
  "Rute til $0"
 ],
 "Routed network": [
  null,
  "Rutet nettverk"
 ],
 "Run": [
  null,
  "Kjør"
 ],
 "Run unattended installation": [
  null,
  "Kjør installasjon uten tilsyn"
 ],
 "Run when host boots": [
  null,
  "Kjør når verten starter"
 ],
 "Running": [
  null,
  "Kjører"
 ],
 "SPICE TLS port": [
  null,
  "SPICE TLS-port"
 ],
 "SPICE address": [
  null,
  "SPICE-adresse"
 ],
 "SPICE port": [
  null,
  "SPICE-port"
 ],
 "Save": [
  null,
  "Lagre"
 ],
 "Sealed-case PC": [
  null,
  ""
 ],
 "Select console type": [
  null,
  "Velg konsolltype"
 ],
 "Send key": [
  null,
  "Send nøkkel"
 ],
 "Send non-maskable interrupt": [
  null,
  ""
 ],
 "Serial console": [
  null,
  "Seriell konsoll"
 ],
 "Session": [
  null,
  "Økt"
 ],
 "Set DHCP range": [
  null,
  ""
 ],
 "Set manually": [
  null,
  "Sett manuelt"
 ],
 "Set time": [
  null,
  ""
 ],
 "Setting the user passwords for unattended installation requires starting the VM when creating it": [
  null,
  "Hvis du skal angi brukerpassord for ubetjent installasjon, må du starte VM når du oppretter den"
 ],
 "Shell script": [
  null,
  "Shell-skript"
 ],
 "Shift+Insert": [
  null,
  "Shift+Insert"
 ],
 "Show additional options": [
  null,
  "Vis flere alternativer"
 ],
 "Shut down": [
  null,
  ""
 ],
 "Shut off": [
  null,
  ""
 ],
 "Shut off the VM in order to edit firmware configuration": [
  null,
  "Slå av VM for å redigere fastvarekonfigurasjon"
 ],
 "Shutting down": [
  null,
  "Slår av"
 ],
 "Single rank": [
  null,
  ""
 ],
 "Size": [
  null,
  "Størrelse"
 ],
 "Snapshot failed to be created": [
  null,
  "Øyeblikksbilde kunne ikke opprettes"
 ],
 "Snapshots": [
  null,
  "Øyeblikksbilder"
 ],
 "Sockets": [
  null,
  ""
 ],
 "Source": [
  null,
  "Kilde"
 ],
 "Source format": [
  null,
  "Kildeformat"
 ],
 "Source path": [
  null,
  "Kildesti"
 ],
 "Source path should not be empty": [
  null,
  "Kildestien skal ikke være tom"
 ],
 "Source should start with http, ftp or nfs protocol": [
  null,
  "Kilden skal starte med http-, ftp- eller nfs-protokoll"
 ],
 "Source volume group": [
  null,
  ""
 ],
 "Space-saving computer": [
  null,
  ""
 ],
 "Specific time": [
  null,
  "Spesifikk tid"
 ],
 "Start": [
  null,
  "Start"
 ],
 "Start libvirt": [
  null,
  "Start libvirt"
 ],
 "Start pool when host boots": [
  null,
  "Start pool når verten starter"
 ],
 "Start should not be empty": [
  null,
  "Start skal ikke være tom"
 ],
 "Startup": [
  null,
  ""
 ],
 "State": [
  null,
  "Tilstand"
 ],
 "Stick PC": [
  null,
  ""
 ],
 "Storage": [
  null,
  "Lagring"
 ],
 "Storage pool $0 failed to get activated": [
  null,
  "Lagrinrgspool $0 kunne ikke aktiveres"
 ],
 "Storage pool $0 failed to get deactivated": [
  null,
  "Lagringspool $0 kunne ikke deaktiveres"
 ],
 "Storage pool failed to be created": [
  null,
  "Lagrings-pool kunne ikke opprettes"
 ],
 "Storage pool name": [
  null,
  "Lagrings-pool navn"
 ],
 "Storage pools": [
  null,
  "Lagrings-pooler"
 ],
 "Storage size must not be 0": [
  null,
  "Lagringsstørrelsen kan ikke være 0"
 ],
 "Storage volume": [
  null,
  "Lagringsvolum"
 ],
 "Storage volume size must not exceed the storage pool's capacity ($0 $1)": [
  null,
  "Lagringsvolumstørrelsen kan ikke overstige kapasiteten på lagrings-poolen ($0 $1)"
 ],
 "Storage volumes": [
  null,
  "Lagringsvolumer"
 ],
 "Storage volumes could not be deleted": [
  null,
  "Lagringsvolumer kunne ikke slettes"
 ],
 "Sub-Chassis": [
  null,
  ""
 ],
 "Sub-Notebook": [
  null,
  ""
 ],
 "Suspended (PM)": [
  null,
  ""
 ],
 "Synchronized": [
  null,
  "Synkronisert"
 ],
 "Synchronized with $0": [
  null,
  "Synkronisert med $0"
 ],
 "Synchronizing": [
  null,
  "Synkroniserer"
 ],
 "System": [
  null,
  "System"
 ],
 "Tablet": [
  null,
  "Nettbrett"
 ],
 "Target": [
  null,
  "Mål"
 ],
 "Target path": [
  null,
  "Målsti"
 ],
 "Target path should not be empty": [
  null,
  "Målstien skal ikke være tom"
 ],
 "The $0 could not be deleted": [
  null,
  "$0 kunne ikke slettes"
 ],
 "The VM is running and will be forced off before deletion.": [
  null,
  "VM kjører og vil bli tvunget avslått før sletting."
 ],
 "The VM needs to be running or shut off to detach this device": [
  null,
  "VM må kjøre eller slås av for å koble fra denne enheten"
 ],
 "The directory on the server being exported": [
  null,
  "Katalogen på serveren som eksporteres"
 ],
 "The logged in user is not permitted to view system modifications": [
  null,
  "Den påloggede brukeren har ikke lov til å se systemendringer"
 ],
 "The passwords do not match.": [
  null,
  "Passordene samsvarer ikke."
 ],
 "The pool is empty": [
  null,
  "Poolen er tom"
 ],
 "The selected operating system does not support unattended installation": [
  null,
  "Det valgte operativsystemet støtter ikke installasjon uten tilsyn"
 ],
 "The selected operating system has minimum memory requirement of $0 $1": [
  null,
  "Det valgte operativsystemet har et minimumskrav til minne på $0 $1"
 ],
 "The selected operating system has minimum storage size requirement of $0 $1": [
  null,
  "Det valgte operativsystemet har et minimumskrav på lagringsstørrelse på $0 $1"
 ],
 "The storage pool could not be deleted": [
  null,
  "Lagrings-poolen kunne ikke slettes"
 ],
 "This VM is transient. Shut it down if you wish to delete it.": [
  null,
  ""
 ],
 "This volume is already used by another VM.": [
  null,
  "Dette volumet brukes allerede av en annen VM."
 ],
 "This volume is already used by: ": [
  null,
  "Dette volumet er allerede brukt av: "
 ],
 "Threads per core": [
  null,
  "Tråder per kjerne"
 ],
 "Time zone": [
  null,
  "Tidssone"
 ],
 "Today": [
  null,
  "I dag"
 ],
 "Total size: $0": [
  null,
  "Total størrelse: $0"
 ],
 "Tower": [
  null,
  ""
 ],
 "Transient VMs don't support editing firmware configuration": [
  null,
  ""
 ],
 "Troubleshoot": [
  null,
  "Feilsøk"
 ],
 "Trying to synchronize with $0": [
  null,
  "Prøver å synkronisere med $0"
 ],
 "Type": [
  null,
  "Type"
 ],
 "Type ID": [
  null,
  "Type ID"
 ],
 "URL (ISO image or distro install tree)": [
  null,
  ""
 ],
 "Unique name": [
  null,
  "Unikt navn"
 ],
 "Unique network name": [
  null,
  "Unikt nettverksnavn"
 ],
 "Unit": [
  null,
  "Enhet"
 ],
 "Unknown": [
  null,
  "Ukjent"
 ],
 "Unknown firmware": [
  null,
  "Ukjent fastvare"
 ],
 "Unplug": [
  null,
  ""
 ],
 "Up to $0 $1 available on the default location": [
  null,
  ""
 ],
 "Up to $0 $1 available on the host": [
  null,
  ""
 ],
 "Url": [
  null,
  "Url"
 ],
 "Usage": [
  null,
  "Bruk"
 ],
 "Use existing": [
  null,
  "Bruk eksisterende"
 ],
 "Used": [
  null,
  "Brukt"
 ],
 "Used by": [
  null,
  "Brukt av"
 ],
 "User login": [
  null,
  ""
 ],
 "User login must not be empty when user password is set": [
  null,
  ""
 ],
 "User password": [
  null,
  "Bruker passord"
 ],
 "User password must not be empty when user login is set": [
  null,
  ""
 ],
 "VCPU settings could not be saved": [
  null,
  "VCPU-innstillingene kunne ikke lagres"
 ],
 "VM $0 already exists": [
  null,
  "VM $0 fnnes allerede"
 ],
 "VM $0 does not exist on $1 connection": [
  null,
  "VM $0 finnes ikke på $1-tilkobling"
 ],
 "VM $0 failed to force reboot": [
  null,
  "VM $0 klarte ikke å tvinge omstart"
 ],
 "VM $0 failed to force shutdown": [
  null,
  "VM $0 kunne ikke tvinge avstenging"
 ],
 "VM $0 failed to get deleted": [
  null,
  "VM $0 kunne ikke slettes"
 ],
 "VM $0 failed to get installed": [
  null,
  "VM $0 kunne ikke installeres"
 ],
 "VM $0 failed to pause": [
  null,
  "VM $0 kunne ikke pause"
 ],
 "VM $0 failed to reboot": [
  null,
  "VM $0 kunne ikke omstartes"
 ],
 "VM $0 failed to resume": [
  null,
  "VM $0 kunne ikke gjenopptas"
 ],
 "VM $0 failed to send NMI": [
  null,
  "VM $0 kunne ikke sende NMI"
 ],
 "VM $0 failed to shutdown": [
  null,
  "VM $0 kunne ikke slås av"
 ],
 "VM $0 failed to start": [
  null,
  "VM $0 kunne ikke startes"
 ],
 "VM state": [
  null,
  "VM-tilstand"
 ],
 "VNC TLS port": [
  null,
  "VNC TLS-port"
 ],
 "VNC address": [
  null,
  "VNC-adresse"
 ],
 "VNC console": [
  null,
  "VNC konsoll"
 ],
 "VNC port": [
  null,
  "VNC-port"
 ],
 "Vendor": [
  null,
  "Leverandør"
 ],
 "View automation script": [
  null,
  "Vis automatiseringsskript"
 ],
 "Virtual Machines": [
  null,
  "Virtuelle maskiner"
 ],
 "Virtual machines": [
  null,
  "Virtuelle maskiner"
 ],
 "Virtual machines management": [
  null,
  "Administrasjon av virtuelle maskiner"
 ],
 "Virtual network": [
  null,
  "Virtuelt nettverk"
 ],
 "Virtual network failed to be created": [
  null,
  "Kunne ikke opprette et virtuelt nettverk"
 ],
 "Virtualization service (libvirt) is not active": [
  null,
  "Virtualiseringstjeneste (libvirt) er ikke aktiv"
 ],
 "Volume": [
  null,
  "Volum"
 ],
 "Volume failed to be created": [
  null,
  "Volumet kunne ikke opprettes"
 ],
 "Volume group name": [
  null,
  "Volumgruppenavn"
 ],
 "Volume group name should not be empty": [
  null,
  "Volumgruppenavnet skal ikke være tomt"
 ],
 "WWPN": [
  null,
  "WWPN"
 ],
 "Waiting for other software management operations to finish": [
  null,
  "Venter på at andre programvareadministrasjons-operasjoner skal fullføres"
 ],
 "Writeable": [
  null,
  "Skrivbar"
 ],
 "Writeable and shared": [
  null,
  "Skrivbar og delt"
 ],
 "Yesterday": [
  null,
  "I går"
 ],
 "You need to select the most closely matching operating system": [
  null,
  "Du må velge det operativsystemet som passer best"
 ],
 "[$0 bytes of binary data]": [
  null,
  "[$0 bytes med binære data]"
 ],
 "[binary data]": [
  null,
  "[binære data]"
 ],
 "[no data]": [
  null,
  "[ingen data]"
 ],
 "active": [
  null,
  "aktiv"
 ],
 "bridge": [
  null,
  "bridge"
 ],
 "cdrom": [
  null,
  "cdrom"
 ],
 "custom": [
  null,
  "egendefinert"
 ],
 "direct": [
  null,
  "direkte"
 ],
 "disabled": [
  null,
  "deaktivert"
 ],
 "disk": [
  null,
  "disk"
 ],
 "down": [
  null,
  "nede"
 ],
 "edit": [
  null,
  "rediger"
 ],
 "enabled": [
  null,
  "aktivert"
 ],
 "ethernet": [
  null,
  "ethernet"
 ],
 "host": [
  null,
  "vert"
 ],
 "host device": [
  null,
  ""
 ],
 "host passthrough": [
  null,
  ""
 ],
 "hostdev": [
  null,
  "hostdev"
 ],
 "iSCSI direct target": [
  null,
  "iSCSI direkte mål"
 ],
 "iSCSI initiator IQN": [
  null,
  ""
 ],
 "iSCSI target": [
  null,
  "iSCSI mål"
 ],
 "iSCSI target IQN": [
  null,
  "iSCSI mål IQN"
 ],
 "iso": [
  null,
  "iso"
 ],
 "libvirt": [
  null,
  "libvirt"
 ],
 "mcast": [
  null,
  "mcast"
 ],
 "network": [
  null,
  "nettverk"
 ],
 "no": [
  null,
  "nei"
 ],
 "no state saved": [
  null,
  "ingen tilstand lagret"
 ],
 "password quality": [
  null,
  "passordkvalitet"
 ],
 "pxe": [
  null,
  "pxe"
 ],
 "qcow2": [
  null,
  "qcow2"
 ],
 "qemu": [
  null,
  "qemu"
 ],
 "redirected device": [
  null,
  ""
 ],
 "server": [
  null,
  "server"
 ],
 "show less": [
  null,
  "vis mindre"
 ],
 "show more": [
  null,
  "vis mer"
 ],
 "udp": [
  null,
  "udp"
 ],
 "up": [
  null,
  "opp"
 ],
 "user": [
  null,
  "bruker"
 ],
 "vCPU count": [
  null,
  ""
 ],
 "vCPU maximum": [
  null,
  ""
 ],
 "vCPUs": [
  null,
  "vCPUer"
 ],
 "vhostuser": [
  null,
  "vhostuser"
 ],
 "view more...": [
  null,
  "se mer..."
 ],
 "virt-install package needs to be installed on the system in order to clone VMs": [
  null,
  "virt-install-pakken må installeres på systemet for å klone virtuelle maskiner"
 ],
 "virt-install package needs to be installed on the system in order to create new VMs": [
  null,
  "virt-install-pakken må installeres på systemet for å opprette nye virtuelle maskiner"
 ],
 "virt-install package needs to be installed on the system in order to edit this attribute": [
  null,
  "virt-install-pakken må installeres på systemet for å redigere dette attributtet"
 ],
 "vm": [
  null,
  "vm"
 ],
 "yes": [
  null,
  "ja"
 ]
});
