cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "fi",
  "x-generator": "Weblate 4.6.2"
 },
 "$0 CPU configuration": [
  null,
  "$0 CPU :n kokoonpano"
 ],
 "$0 Network": [
  "$0 Networks",
  "$0 verkko",
  "$0 verkkoa"
 ],
 "$0 Storage pool": [
  "$0 Storage pools",
  "$0 tallennustilavaranto",
  "$0 tallennustilavarantoa"
 ],
 "$0 day": [
  "$0 days",
  "$0 päivä",
  "$0 päivää"
 ],
 "$0 hour": [
  "$0 hours",
  "$0 tunti",
  "$0 tuntia"
 ],
 "$0 is available for most operating systems. To install it, search for it in GNOME Software or run the following:": [
  null,
  "$0 on saatavilla useimmille käyttöjärjestelmille. Asentaaksesi sen, hae sitä GNOME Softwaresta, tai aja seuraava komento:"
 ],
 "$0 is not available from any repository.": [
  null,
  "$0 ei ole saatavilla mistään ohjelmistovarastosta."
 ],
 "$0 memory adjustment": [
  null,
  "$0 muistin säätö"
 ],
 "$0 minute": [
  "$0 minutes",
  "$0 minuutti",
  "$0 minuuttia"
 ],
 "$0 month": [
  "$0 months",
  "$0 kuukausi",
  "$0 kuukautta"
 ],
 "$0 network": [
  null,
  "$0 verkko"
 ],
 "$0 vCPU": [
  "$0 vCPUs",
  "$0 vCPU",
  "$0 vCPU:ta"
 ],
 "$0 vCPU details": [
  null,
  "$0 vCPU:n yksityiskohdat"
 ],
 "$0 virtual network interface settings": [
  null,
  "$0 virtuaalisen verkkoliitännän asetukset"
 ],
 "$0 week": [
  "$0 weeks",
  "$0 viikko",
  "$0 viikkoa"
 ],
 "$0 will be installed.": [
  null,
  "$0 asennetaan."
 ],
 "$0 year": [
  "$0 years",
  "$0 vuosi",
  "$0 vuotta"
 ],
 "1 day": [
  null,
  "1 päivä"
 ],
 "1 hour": [
  null,
  "1 tunti"
 ],
 "1 minute": [
  null,
  "1 minuutti"
 ],
 "1 week": [
  null,
  "1 viikko"
 ],
 "20 minutes": [
  null,
  "20 minuuttia"
 ],
 "40 minutes": [
  null,
  "40 minuuttia"
 ],
 "5 minutes": [
  null,
  "5 minuuttia"
 ],
 "6 hours": [
  null,
  "6 tuntia"
 ],
 "60 minutes": [
  null,
  "60 minuuttia"
 ],
 "Absent": [
  null,
  "Poissa"
 ],
 "Access": [
  null,
  "Pääsy"
 ],
 "Activate": [
  null,
  "Aktivoi"
 ],
 "Activate the storage pool to administer volumes": [
  null,
  "Aktivoi varastointivaranto taltioiden hallitsemiseksi"
 ],
 "Add": [
  null,
  "Lisää"
 ],
 "Add disk": [
  null,
  "Lisää levy"
 ],
 "Add network interface": [
  null,
  "Lisää verkkoliitäntä"
 ],
 "Add virtual network interface": [
  null,
  "Lisää virtuaalinen verkkoliitäntä"
 ],
 "Additional": [
  null,
  "Ylimääräinen"
 ],
 "Additional packages:": [
  null,
  "Ylimääräiset paketit:"
 ],
 "Address": [
  null,
  "Osoite"
 ],
 "Address not within subnet": [
  null,
  "Osoite ei aliverkossa"
 ],
 "Advanced TCA": [
  null,
  "Edistynyt TCA"
 ],
 "After deleting the snapshot, all its captured content will be lost.": [
  null,
  "Tilannevedoksen poistamisen jälkeen kaikki siepattu sisältö menetetään."
 ],
 "All": [
  null,
  "Kaikki"
 ],
 "All logs": [
  null,
  "Kaikki lokit"
 ],
 "All-in-one": [
  null,
  "Kaikki yhdessä"
 ],
 "Always attach": [
  null,
  "Kiinnitä aina"
 ],
 "Ansible": [
  null,
  "Ansible"
 ],
 "Ansible roles documentation": [
  null,
  "Ansible -roolien dokumentointi"
 ],
 "Apply": [
  null,
  "Toteuta"
 ],
 "Attaching it will make this disk shareable for every VM using it.": [
  null,
  "Sen liittäminen tekee levystä jaettavan jokaiselle sitä käyttävälle virtuaalikoneelle."
 ],
 "Automatic": [
  null,
  "Automaattinen"
 ],
 "Automatically start libvirt on boot": [
  null,
  "Käynnistä libvirt automaattisesti käynnistyksen yhteydessä"
 ],
 "Automatically using NTP": [
  null,
  "Käytetään automaattisesti NTP:tä"
 ],
 "Automatically using specific NTP servers": [
  null,
  "Käytetään automaattisesti tiettyjä NTP-palvelimia"
 ],
 "Automation script": [
  null,
  "Automaatio-komentosarja"
 ],
 "Autostart": [
  null,
  "Automaattikäynnistys"
 ],
 "Blade": [
  null,
  "Terä"
 ],
 "Blade enclosure": [
  null,
  "Teräkotelo"
 ],
 "Blocked": [
  null,
  "Estetty"
 ],
 "Boot order": [
  null,
  "Käynnistysjärjestys"
 ],
 "Boot order settings could not be saved": [
  null,
  "Käynnistysjärjestysasetuksia ei voitu tallentaa"
 ],
 "Bus": [
  null,
  "Väylä"
 ],
 "Bus expansion chassis": [
  null,
  "Väylän laajennusalusta"
 ],
 "CD/DVD disc": [
  null,
  "CD/DVD-levy"
 ],
 "CPU": [
  null,
  "Suoritin"
 ],
 "CPU configuration could not be saved": [
  null,
  "CPU:n kokoonpanoa ei voitu tallentaa"
 ],
 "CPU type": [
  null,
  "CPU-tyyppi"
 ],
 "Cache": [
  null,
  "Välimuisti"
 ],
 "Cancel": [
  null,
  "Peru"
 ],
 "Cannot schedule event in the past": [
  null,
  "Tapahtumaa ei voi aikatauluttaa menneisyyteen"
 ],
 "Capacity": [
  null,
  "Koko"
 ],
 "Change": [
  null,
  "Vaihda"
 ],
 "Change firmware": [
  null,
  "Vaihda laiteohjelmisto"
 ],
 "Change system time": [
  null,
  "Vaihda järjestelmän aika"
 ],
 "Changes will take effect after shutting down the VM": [
  null,
  "Muutokset tulevat voimaan virtuaalikoneen sammuttamisen jälkeen"
 ],
 "Checking installed software": [
  null,
  "Tarkistetaan asennettu ohjelmisto"
 ],
 "Choose an operating system": [
  null,
  "Valitse käyttöjärjestelmä"
 ],
 "Clicking \"Launch remote viewer\" will download a .vv file and launch $0.": [
  null,
  "Painamalla \"Käynnistä etäkatseluohjelma\" lataat .vv-tiedoston ja käynnistät $0."
 ],
 "Clone": [
  null,
  "Kloonaa"
 ],
 "Close": [
  null,
  "Sulje"
 ],
 "Cloud base image": [
  null,
  "Pilvipohjainen levykuva"
 ],
 "Cloud init parameters": [
  null,
  "pilvi-init:n parametrit"
 ],
 "Compact PCI": [
  null,
  "Kompakti PCI"
 ],
 "Confirm this action": [
  null,
  "Vahvista tämä toimi"
 ],
 "Connect": [
  null,
  "Yhdistä"
 ],
 "Connect with any viewer application for following protocols": [
  null,
  "Yhdistä mihin tahansa katseluohjelmaan seuraaviin protokolliin"
 ],
 "Connecting to virtualization service": [
  null,
  "Yhdistetään virtualisointipalveluun"
 ],
 "Connection": [
  null,
  "Yhteys"
 ],
 "Console": [
  null,
  "Konsoli"
 ],
 "Convertible": [
  null,
  "Muunnettavissa"
 ],
 "Copy": [
  null,
  "Kopio"
 ],
 "Copy to clipboard": [
  null,
  "Kopioi leikepöydälle"
 ],
 "Cores per socket": [
  null,
  "Ytimiä per kanta"
 ],
 "Could not revert to snapshot": [
  null,
  "Tilannevedoksen palauttaminen epäonnistui"
 ],
 "Crashed": [
  null,
  "Kaatui"
 ],
 "Create": [
  null,
  "Luo"
 ],
 "Create VM": [
  null,
  "Luo VM"
 ],
 "Create a clone VM based on $0": [
  null,
  "Luo $0:een perustuva klooninen virtuaalikone"
 ],
 "Create new": [
  null,
  "Luo uusi"
 ],
 "Create new task file with this content.": [
  null,
  "Luo uusi tehtävätiedosto tällä sisällöllä."
 ],
 "Create new virtual machine": [
  null,
  "Luo uusi virtuaalikone"
 ],
 "Create new volume": [
  null,
  "Luo uusi taltio"
 ],
 "Create snapshot": [
  null,
  "Luo tilannevedos"
 ],
 "Create storage pool": [
  null,
  "Luo varastointivaranto"
 ],
 "Create storage volume": [
  null,
  "Luo varastointitaltio"
 ],
 "Create virtual network": [
  null,
  "Luo virtuaaliverkko"
 ],
 "Create volume": [
  null,
  "Luo taltio"
 ],
 "Creating VM": [
  null,
  "Virtuaalikoneen luominen"
 ],
 "Creating VM installation": [
  null,
  "Luodaan virtuaalikoneen asennus"
 ],
 "Creation of VM $0 failed": [
  null,
  "Virtuaalikoneen $0 luominen epäonnistui"
 ],
 "Creation time": [
  null,
  "Luomisaika"
 ],
 "Ctrl+Alt+$0": [
  null,
  "Ctrl+Alt+$0"
 ],
 "Ctrl+Insert": [
  null,
  "Ctrl+Insert"
 ],
 "Current": [
  null,
  "Nykyinen"
 ],
 "Current allocation": [
  null,
  "Nykyinen kohdentaminen"
 ],
 "Custom firmware: $0": [
  null,
  "Mukautettu laiteohjelmisto: $0"
 ],
 "Custom path": [
  null,
  "Mukautettu polku"
 ],
 "DHCP range": [
  null,
  "DHCP-alue"
 ],
 "Deactivate": [
  null,
  "Deaktivoi"
 ],
 "Delay": [
  null,
  "Viive"
 ],
 "Delete": [
  null,
  "Poista"
 ],
 "Delete $0 volume": [
  "Delete $0 volumes",
  "Poista $0 taltio",
  "Poista $0 taltiota"
 ],
 "Delete associated storage files:": [
  null,
  "Poista liittyvät tallennustiedostot:"
 ],
 "Delete content": [
  null,
  "Poista sisältö"
 ],
 "Delete storage pool $0": [
  null,
  "Poista varastointivaranto $0"
 ],
 "Delete the volumes inside this pool": [
  null,
  "Poista tämän varannon sisäiset taltiot"
 ],
 "Deleting an inactive storage pool will only undefine the pool. Its content will not be deleted.": [
  null,
  "Passiivisen varastointivarannon poistaminen poistaa vain määrittelyn varannosta. Sen sisältöä ei poisteta."
 ],
 "Description": [
  null,
  "Kuvaus"
 ],
 "Desktop": [
  null,
  "Työpöytä"
 ],
 "Desktop viewer": [
  null,
  "Työpöydän katseluohjelma"
 ],
 "Detach the disks using this pool from any VMs before attempting deletion.": [
  null,
  "Irrota tätä varantoa käyttävät levyt kaikista virtuaalikoneista ennen poistoyritystä."
 ],
 "Detachable": [
  null,
  "Irrotettava"
 ],
 "Device": [
  null,
  "Laite"
 ],
 "Devices": [
  null,
  "Laitteet"
 ],
 "Disconnect": [
  null,
  "Katkaise yhteys"
 ],
 "Disconnected from serial console. Click the connect button.": [
  null,
  "Irrotettu sarjakonsolista. Napsauta yhdistä-painiketta."
 ],
 "Disk $0 fail to get detached from VM $1": [
  null,
  "Levyä $0 ei voida irrottaa virtuaalikoneesta $1"
 ],
 "Disk failed to be attached": [
  null,
  "Levyn liittäminen epäonnistui"
 ],
 "Disk failed to be created": [
  null,
  "Levyn luominen epäonnistui"
 ],
 "Disk image file": [
  null,
  "Levykuvatiedosto"
 ],
 "Disk settings could not be saved": [
  null,
  "Levyn asetuksia ei voitu tallentaa"
 ],
 "Disk-only snapshot": [
  null,
  "Vain levy -tilannevedos"
 ],
 "Disks": [
  null,
  "Levyt"
 ],
 "Docking station": [
  null,
  "Telakka"
 ],
 "Domain has crashed": [
  null,
  "Toimialue on kaatunut"
 ],
 "Domain is blocked on resource": [
  null,
  "Toimialue on estetty resurssilla"
 ],
 "Download an OS": [
  null,
  "Lataa käyttöjärjestelmä"
 ],
 "Downloading $0": [
  null,
  "Ladataan $0"
 ],
 "Dual rank": [
  null,
  "Kaksinkertainen sijoitus"
 ],
 "Dying": [
  null,
  "Kuolemassa"
 ],
 "Edit": [
  null,
  "Muokkaa"
 ],
 "Edit $0 attributes": [
  null,
  "Muokkaa $0 attribuuttia"
 ],
 "Embedded PC": [
  null,
  "Sulautettu tietokone"
 ],
 "Emulated machine": [
  null,
  "Sulautettu kone"
 ],
 "End": [
  null,
  "Loppu"
 ],
 "End should not be empty": [
  null,
  "Loppu ei saa olla tyhjä"
 ],
 "Error message": [
  null,
  "Virheviesti"
 ],
 "Error running semanage to discover system modifications": [
  null,
  "Virhe suoritettaessa semanage:ta järjestelmän muutosten löytämiseksi"
 ],
 "Excellent password": [
  null,
  "Erinomainen salasana"
 ],
 "Existing disk image on host's file system": [
  null,
  "Poistutaan levykuvasta isännän tiedostojärjestelmässä"
 ],
 "Expand": [
  null,
  "Laajenna"
 ],
 "Expansion chassis": [
  null,
  "Laajennusrunko"
 ],
 "Failed": [
  null,
  "Epäonnistui"
 ],
 "Failed to change firmware": [
  null,
  "Laiteohjelmiston vaihtaminen epäonnistui"
 ],
 "Failed to change password": [
  null,
  "Salasanan vaihtaminen epäonnistui"
 ],
 "Failed to clone VM $0": [
  null,
  "VM:n $0 kloonaus epäonnistui"
 ],
 "Failed to fetch the IP addresses of the interfaces present in $0": [
  null,
  "$0:ssa olevien liitäntöjen IP-osoitteiden noutaminen epäonnistui"
 ],
 "Failed to send key Ctrl+Alt+$0 to VM $1": [
  null,
  "Näppäimen Ctrl+Alt+$0 lähettäminen virtuaalikoneeseen $1 epäonnistui"
 ],
 "Fewer than the maximum number of virtual CPUs should be enabled.": [
  null,
  "Alle virtuaalisten suorittimien enimmäismäärän tulisi olla käytössä."
 ],
 "File": [
  null,
  "Tiedosto"
 ],
 "Filesystem directory": [
  null,
  "Tiedostojärjestelmän hakemisto"
 ],
 "Filter by name": [
  null,
  "Suodata nimen mukaan"
 ],
 "Firmware": [
  null,
  "Laiteohjelmisto"
 ],
 "Force reboot": [
  null,
  "Pakota uudelleenkäynnistys"
 ],
 "Force shut down": [
  null,
  "Pakota sammutus"
 ],
 "Format": [
  null,
  "Alusta"
 ],
 "Forward mode": [
  null,
  "Eteenpäin-tila"
 ],
 "Forwarding mode": [
  null,
  "Edelleenlähetystila"
 ],
 "General": [
  null,
  "Yleinen"
 ],
 "Generate automatically": [
  null,
  "Luo automaattisesti"
 ],
 "GiB": [
  null,
  "Git"
 ],
 "Go to VMs list": [
  null,
  "Siirry virtuaalikoneiden luetteloon"
 ],
 "Go to now": [
  null,
  "Mene nyt"
 ],
 "Handheld": [
  null,
  "Kädessä pidettävä"
 ],
 "Hide additional options": [
  null,
  "Piilota lisävaihtoehdot"
 ],
 "Host": [
  null,
  "Kone"
 ],
 "Host device": [
  null,
  "Isäntälaite"
 ],
 "Host name": [
  null,
  "Isäntänimi"
 ],
 "Host should not be empty": [
  null,
  "Nimen ei saa olla tyhjä"
 ],
 "Hours must be a number between 0 and 23": [
  null,
  "Tunnin on oltava luku välillä 0 ja 23"
 ],
 "Hypervisor details": [
  null,
  "Hypervisorin yksityiskohdat"
 ],
 "ID": [
  null,
  "Tunniste"
 ],
 "IP address": [
  null,
  "IP-osoite"
 ],
 "IP configuration": [
  null,
  "IP-määritykset"
 ],
 "IPv4 address": [
  null,
  "IPv4-osoite"
 ],
 "IPv4 and IPv6": [
  null,
  "IPv4 ja IPv6"
 ],
 "IPv4 network": [
  null,
  "IPv4-verkko"
 ],
 "IPv4 network should not be empty": [
  null,
  "IPv4-verkko ei tulisi olla tyhjä"
 ],
 "IPv4 only": [
  null,
  "IPv4 vain"
 ],
 "IPv6 address": [
  null,
  "IPv6-osoite"
 ],
 "IPv6 network": [
  null,
  "IPv6-verkko"
 ],
 "IPv6 network should not be empty": [
  null,
  "IPv6-verkko ei tulisi olla tyhjä"
 ],
 "IPv6 only": [
  null,
  "IPv6 vain"
 ],
 "Idle": [
  null,
  "Jouten"
 ],
 "Immediately start VM": [
  null,
  "Käynnistä virtuaalikone välittömästi"
 ],
 "Import": [
  null,
  "Tuo"
 ],
 "Import VM": [
  null,
  "Tuo virtuaalikone"
 ],
 "Import a virtual machine": [
  null,
  "Tuo virtuaalikone"
 ],
 "In most configurations, macvtap does not work for host to guest network communication.": [
  null,
  "Useimmissa kokoonpanoissa macvtap ei toimi isäntä-vieras-verkkoyhteydessä."
 ],
 "Initiator": [
  null,
  "Aloittaja"
 ],
 "Initiator IQN should not be empty": [
  null,
  "Aloittaja IQN ei saa olla tyhjä"
 ],
 "Install": [
  null,
  "Asennus"
 ],
 "Install software": [
  null,
  "Asennetaan ohjelmistoja"
 ],
 "Installation source": [
  null,
  "Asennuslähde"
 ],
 "Installation source must not be empty": [
  null,
  "Asennuslähteen ei tulisi olla tyhjä"
 ],
 "Installation type": [
  null,
  "Asennustyyppi"
 ],
 "Installing $0": [
  null,
  "Asennetaan $0"
 ],
 "Interface type": [
  null,
  "Liitäntätyyppi"
 ],
 "Invalid IPv4 address": [
  null,
  "Ei kelvollinen IPv4-osoite"
 ],
 "Invalid IPv4 mask or prefix length": [
  null,
  "Virheellinen IPv4-peitteen tai etuliitteen pituus"
 ],
 "Invalid IPv6 address": [
  null,
  "Ei kelvollinen IPv6-osoite"
 ],
 "Invalid IPv6 prefix": [
  null,
  "Virheellinen IPv6-etuliite"
 ],
 "Invalid date format": [
  null,
  "Virheellinen päivämuoto"
 ],
 "Invalid date format and invalid time format": [
  null,
  "Virheellinen päivämuoto ja aikamuoto"
 ],
 "Invalid file permissions": [
  null,
  "Virheelliset tiedosto-oikeudet"
 ],
 "Invalid filename": [
  null,
  "Virheellinen tiedostonimi"
 ],
 "Invalid time format": [
  null,
  "Virheellinen aikamuoto"
 ],
 "Invalid timezone": [
  null,
  "Virheellinen aikavyöhyke"
 ],
 "IoT gateway": [
  null,
  "IoT -yhdyskäytävä"
 ],
 "Isolated network": [
  null,
  "Eristetty verkko"
 ],
 "LVM volume group": [
  null,
  "LVM-taltioryhmä"
 ],
 "Laptop": [
  null,
  "Kannettava"
 ],
 "Launch remote viewer": [
  null,
  "Käynnistä etäkatselin"
 ],
 "Learn more": [
  null,
  "Opi lisää"
 ],
 "Leave the password blank if you do not wish to have a root account created": [
  null,
  "Jätä salasana tyhjäksi, jos et halua root:n tilin luomista"
 ],
 "Leave the password blank if you do not wish to have a user account created": [
  null,
  "Jätä salasana tyhjäksi, jos et halua käyttäjätilin luomista"
 ],
 "Leave the password blank if you do not wish to set a root password": [
  null,
  "Jätä salasana tyhjäksi, jos et halua root:n tilin luomista"
 ],
 "Libvirt did not detect any UEFI/OVMF firmware image installed on the host": [
  null,
  "Libvirt ei havainnut isäntään asennettuja UEFI/OVMF-laiteohjelmistokuvia"
 ],
 "Libvirt or hypervisor does not support UEFI": [
  null,
  "Libvirt tai hypervisori ei tue UEFI:a"
 ],
 "Loading resources": [
  null,
  "Ladataan resursseja"
 ],
 "Loading system modifications...": [
  null,
  "Ladataan järjestelmän muutoksia ..."
 ],
 "Loading...": [
  null,
  "Ladataan..."
 ],
 "Local install media (ISO image or distro install tree)": [
  null,
  "Paikallinen asennusmedia (ISO-kuvan tai jakelun asennuspuu)"
 ],
 "Log messages": [
  null,
  "Kirjaa viestit"
 ],
 "Low profile desktop": [
  null,
  "Matalan tason työpöytä"
 ],
 "Lunch box": [
  null,
  "Eväslaatikko"
 ],
 "MAC": [
  null,
  "MAC"
 ],
 "MAC address": [
  null,
  "MAC-osoite"
 ],
 "Machine must be shut off before changing bus type": [
  null,
  "Kone on sammutettava ennen väylätyypin vaihtamista"
 ],
 "Machine must be shut off before changing cache mode": [
  null,
  "Kone on sammutettava ennen välimuistiin tilan vaihtamista"
 ],
 "Main server chassis": [
  null,
  "Pääpalvelimen runko"
 ],
 "Managing virtual machines": [
  null,
  "Virtuaalikoneiden hallinta"
 ],
 "Manual connection": [
  null,
  "Manuaalinen yhteys"
 ],
 "Manually": [
  null,
  "Manuaalisesti"
 ],
 "Mask or prefix length": [
  null,
  "Peitteen tai etuliitteen pituus"
 ],
 "Mask or prefix length should not be empty": [
  null,
  "Peitteen tai etuliitteen pituus ei tulisi olla tyhjä"
 ],
 "Maximum allocation": [
  null,
  "Enimmäisvaraus"
 ],
 "Maximum memory could not be saved": [
  null,
  "Enimmäismuistia ei voitu tallentaa"
 ],
 "Maximum number of virtual CPUs allocated for the guest OS": [
  null,
  "Vieraskäyttöjärjestelmälle varattu virtuaalisten suorittimien enimmäismäärä"
 ],
 "Maximum number of virtual CPUs allocated for the guest OS, which must be between 1 and $0": [
  null,
  "Vieraskäyttöjärjestelmälle varattu virtuaalisten suorittimien enimmäismäärä, jonka on oltava välillä 1 ja $0"
 ],
 "Maximum transmission unit": [
  null,
  "Enimmäislähetysyksikkö"
 ],
 "Memory": [
  null,
  "Muisti"
 ],
 "Memory could not be saved": [
  null,
  "Muistia ei voitu tallentaa"
 ],
 "Memory must not be 0": [
  null,
  "Muisti ei saa olla 0"
 ],
 "Message to logged in users": [
  null,
  "Viesti sisäänkirjautuneille käyttäjille"
 ],
 "MiB": [
  null,
  "Mit"
 ],
 "Mini PC": [
  null,
  "Mini-tietokone"
 ],
 "Mini tower": [
  null,
  "Mini-torni"
 ],
 "Minutes must be a number between 0 and 59": [
  null,
  "Minuuttien on oltava luku välillä 0 ja 59"
 ],
 "Mode": [
  null,
  "Tila"
 ],
 "Model": [
  null,
  "Malli"
 ],
 "Model type": [
  null,
  "Mallityyppi"
 ],
 "Multi-system chassis": [
  null,
  "Monijärjestelmäinen alusta"
 ],
 "NAT to $0": [
  null,
  "NAT $0:een"
 ],
 "NIC $0 of VM $1 failed to change state": [
  null,
  "Virtuaalikoneen $1 verkkokortti $0 ei muuttanut tilaa"
 ],
 "NTP server": [
  null,
  "NTP-palvelin"
 ],
 "Name": [
  null,
  "Nimi"
 ],
 "Name contains invalid characters": [
  null,
  "Nimi sisältää laittomia merkkejä"
 ],
 "Name must not be empty": [
  null,
  "Nimi ei saa olla tyhjä"
 ],
 "Name should not be empty": [
  null,
  "Nime ei tulisi olla tyhjä"
 ],
 "Name: ": [
  null,
  "Nimi: "
 ],
 "Need at least one NTP server": [
  null,
  "Tarvitaan vähintään yksi NTP-palvelin"
 ],
 "Netmask": [
  null,
  "Verkkopeite"
 ],
 "Network $0 failed to get activated": [
  null,
  "Verkkoa $0 ei voitu aktivoida"
 ],
 "Network $0 failed to get deactivated": [
  null,
  "Verkkoa $0 ei voitu poistaa käytöstä"
 ],
 "Network boot (PXE)": [
  null,
  "Verkkokäynnistys (PXE)"
 ],
 "Network file system": [
  null,
  "Verkkotiedostojärjestelmä"
 ],
 "Network interface settings could not be saved": [
  null,
  "Verkkoliitännän asetuksia ei voitu tallentaa"
 ],
 "Network selection does not support PXE.": [
  null,
  "Verkon valinta ei tue PXE:ta."
 ],
 "Networks": [
  null,
  "Verkot"
 ],
 "New password was not accepted": [
  null,
  "Uutta salasanaa ei hyväksytty"
 ],
 "New volume name": [
  null,
  "Uusi taltion nimi"
 ],
 "No VM is running or defined on this host": [
  null,
  "Mikään virtuaalikone ei ole käynnissä tai määritelty tässä isännässä"
 ],
 "No boot device found": [
  null,
  "Käynnistyslaitetta ei löytynyt"
 ],
 "No connection available": [
  null,
  "Ei yhteytta saatavilla"
 ],
 "No delay": [
  null,
  "Ei v iivettä"
 ],
 "No description": [
  null,
  "Ei kuvausta"
 ],
 "No disks defined for this VM": [
  null,
  "Tälle virtuaalikoneelle ei ole määritetty levyjä"
 ],
 "No network devices": [
  null,
  "Ei verkkolaitteita"
 ],
 "No network interfaces defined for this VM": [
  null,
  "Tälle virtuaalikoneelle ei ole määritetty verkkoliitäntöjä"
 ],
 "No network is defined on this host": [
  null,
  "Tälle isännälle ei ole määritetty verkkoa"
 ],
 "No networks available": [
  null,
  "Verkkoja ei ole käytettävissä"
 ],
 "No parent": [
  null,
  "Ei vanhempi"
 ],
 "No snapshots defined for this VM": [
  null,
  "Tälle virtuaalikoneelle ei ole määritetty tilannevedoksia"
 ],
 "No state": [
  null,
  "Ei tilaa"
 ],
 "No storage": [
  null,
  "Ei tallennustilaa"
 ],
 "No storage pool is defined on this host": [
  null,
  "Tälle isännälle ei ole määritetty varastointivarantoa"
 ],
 "No storage pools available": [
  null,
  "Ei varastointivarantoja saatavilla"
 ],
 "No storage volumes defined for this storage pool": [
  null,
  "Tälle varastointivarannolle ei ole määritetty varastointitaltioita"
 ],
 "No such file or directory": [
  null,
  "Ei tällaista tiedostoa tai hakemistoa"
 ],
 "No system modifications": [
  null,
  "Ei järjestelmän muutoksia"
 ],
 "No virtual networks": [
  null,
  "Ei virtuaaliverkkoja"
 ],
 "Non-persistent network cannot be deleted. It ceases to exists when it's deactivated.": [
  null,
  "Ei-pysyvää verkkoa ei voida poistaa. Se lakkaa olemasta, kun se deaktivoidaan."
 ],
 "Non-persistent storage pool cannot be deleted. It ceases to exists when it's deactivated.": [
  null,
  "Ei-pysyvää varastointivarantoa ei voida poistaa. Se lakkaa olemasta, kun se deaktivoidaan."
 ],
 "None": [
  null,
  "Ei yhtään"
 ],
 "None (isolated network)": [
  null,
  "Ei-eristetty verkko"
 ],
 "Not a valid private key": [
  null,
  "Ei kelvollinen yksityinen avain"
 ],
 "Not synchronized": [
  null,
  "Ei synkronisoitu"
 ],
 "Notebook": [
  null,
  "Muistikirja"
 ],
 "Ok": [
  null,
  "OK"
 ],
 "Old password not accepted": [
  null,
  "Vanhaa salasanaa ei hyväksytty"
 ],
 "One or more selected volumes are used by domains. Detach the disks first to allow volume deletion.": [
  null,
  "Toimialueet käyttävät yhtä tai useampaa valittua taltiota. Irrota levyt ensin, jotta taltio voidaan poistaa."
 ],
 "Only editable when the guest is shut off": [
  null,
  "Muokattavissa vain, kun vieras on sammutettuna"
 ],
 "Open": [
  null,
  "Avaa"
 ],
 "Operating system": [
  null,
  "Käyttöjärjestelmä"
 ],
 "Operation is in progress": [
  null,
  "Toiminto käynnissä"
 ],
 "Other": [
  null,
  "Muu"
 ],
 "Overview": [
  null,
  "Esittely"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit kaatui"
 ],
 "Parent snapshot": [
  null,
  "Vanhempi-tilannevedos"
 ],
 "Password is not acceptable": [
  null,
  "Salasana ei ole hyväksyttävä"
 ],
 "Password is too weak": [
  null,
  "Salasana on liian heikko"
 ],
 "Password not accepted": [
  null,
  "Salasanaa ei hyväksytty"
 ],
 "Paste": [
  null,
  "Siirrä"
 ],
 "Path": [
  null,
  "Polku"
 ],
 "Path on host's filesystem": [
  null,
  "Polku isännän tiedostojärjestelmässä"
 ],
 "Path to ISO file on host's file system": [
  null,
  "Polku ISO-tiedostoon isännän tiedostojärjestelmässä"
 ],
 "Path to cloud image file on host's file system": [
  null,
  "Polku pilvipohjaiseen tiedostoon isännän tiedostojärjestelmässä"
 ],
 "Path to file": [
  null,
  "Polku tiedostoon"
 ],
 "Path to file on host's file system": [
  null,
  "Polku tiedostoon isännän tiedostojärjestelmässä"
 ],
 "Pause": [
  null,
  "Keskeytä"
 ],
 "Paused": [
  null,
  "Keskeytetty"
 ],
 "Peripheral chassis": [
  null,
  "Kehäalusta"
 ],
 "Persistence": [
  null,
  "Pysyvyys"
 ],
 "Persistent": [
  null,
  "Pysyvä"
 ],
 "Physical disk device": [
  null,
  "Fyysinen levylaite"
 ],
 "Physical disk device on host": [
  null,
  "Fyysinen levylaite isännässä"
 ],
 "Pick date": [
  null,
  "Valitse päivämäärä"
 ],
 "Pizza box": [
  null,
  "Pizza-laatikko"
 ],
 "Please choose a storage pool": [
  null,
  "Valitse tallennusvaranto"
 ],
 "Please choose a volume": [
  null,
  "Valitse taltio"
 ],
 "Please enter new volume name": [
  null,
  "Anna uusi taltion nimi"
 ],
 "Please start the virtual machine to access its console.": [
  null,
  "Käynnistä virtuaalikone päästäksesi sen konsoliin."
 ],
 "Plug": [
  null,
  "Kytke"
 ],
 "Pool": [
  null,
  "Varanto"
 ],
 "Pool needs to be active to create volume": [
  null,
  "Varannon on oltava aktiivinen taltion luomiseksi"
 ],
 "Pool type doesn't support volume creation": [
  null,
  "Varannon tyyppi ei tue taltion luomista"
 ],
 "Pool's volumes are used by VMs ": [
  null,
  "Varannon taltioita käyttävät virtuaalikoneet "
 ],
 "Port": [
  null,
  "Portti"
 ],
 "Portable": [
  null,
  "Kannettava"
 ],
 "Preferred number of sockets to expose to the guest.": [
  null,
  "Vieraalle altistettavaksi haluttu pistokkeiden määrä ."
 ],
 "Prefix": [
  null,
  "Etuliite"
 ],
 "Prefix length": [
  null,
  "Etuliitteen pituus"
 ],
 "Prefix length should not be empty": [
  null,
  "Etuliitteen pituuss ei tulisi olla tyhjä"
 ],
 "Present": [
  null,
  "Nykyinen"
 ],
 "Previously taken snapshots allow you to revert to an earlier state if something goes wrong": [
  null,
  "Aiemmin otettujen tilannevedoksien avulla voit palata aikaisempaan tilaan, jos jokin menee pieleen"
 ],
 "Private": [
  null,
  "Yksityinen"
 ],
 "Product": [
  null,
  "Tuote"
 ],
 "Profile": [
  null,
  "Profiili"
 ],
 "Prompting via ssh-add timed out": [
  null,
  "Kysely 'ssh-add':in kautta aikakatkaistiin"
 ],
 "Prompting via ssh-keygen timed out": [
  null,
  "Kysely 'ssh-keygen':in kautta aikakatkaistiin"
 ],
 "Protocol": [
  null,
  "Protokolla"
 ],
 "RAID chassis": [
  null,
  "RAID-runko"
 ],
 "Rack mount chassis": [
  null,
  "Telineen kiinnitysrunko"
 ],
 "Read-only": [
  null,
  "Vain luku"
 ],
 "Reboot": [
  null,
  "Käynnistä uudelleen"
 ],
 "Remote URL": [
  null,
  "Etä-URL"
 ],
 "Remote viewer details": [
  null,
  "Etäkatseluohjelman yksityiskohdat"
 ],
 "Removals:": [
  null,
  "Poistot:"
 ],
 "Remove": [
  null,
  "Poista"
 ],
 "Removing $0": [
  null,
  "Poistetaan $0"
 ],
 "Resume": [
  null,
  "Palauta"
 ],
 "Revert": [
  null,
  "Palaa"
 ],
 "Revert to snapshot $0": [
  null,
  "Palaa tilannevedokseen $0"
 ],
 "Reverting to this snapshot will take the VM back to the time of the snapshot and the current state will be lost, along with any data not captured in a snapshot": [
  null,
  "Palautus tähän tilannevedokseen palauttaa virtuaalikoneen tilannevedoksen aikaan ja nykyinen tila häviää, samoin kuin kaikki tiedot, joita ei ole siepattu tilannevedoksessa"
 ],
 "Root password": [
  null,
  "Root:n salasana"
 ],
 "Route to $0": [
  null,
  "Reitti $0:een"
 ],
 "Routed network": [
  null,
  "Reititetty verkko"
 ],
 "Run": [
  null,
  "Suorita"
 ],
 "Run unattended installation": [
  null,
  "Suorita asennus ilman valvontaa"
 ],
 "Run when host boots": [
  null,
  "Suorita, kun isäntä käynnistyy"
 ],
 "Running": [
  null,
  "Käynnissä"
 ],
 "SPICE TLS port": [
  null,
  "SPICE-TLS -portti"
 ],
 "SPICE address": [
  null,
  "SPICE-osoite"
 ],
 "SPICE port": [
  null,
  "SPICE-portti"
 ],
 "Save": [
  null,
  "Tallenna"
 ],
 "Sealed-case PC": [
  null,
  "Suljettu tietokonekotelo"
 ],
 "Select console type": [
  null,
  "Valitse konsolin tyyppi"
 ],
 "Send key": [
  null,
  "Lähetä avain"
 ],
 "Send non-maskable interrupt": [
  null,
  "Lähetä ei-peitettävä keskeytys"
 ],
 "Serial console": [
  null,
  "Sarjakonsoli"
 ],
 "Session": [
  null,
  "Istunto"
 ],
 "Set DHCP range": [
  null,
  "Määritä DHCP-alue"
 ],
 "Set manually": [
  null,
  "Aseta käsin"
 ],
 "Set time": [
  null,
  "Aseta aika"
 ],
 "Setting the user passwords for unattended installation requires starting the VM when creating it": [
  null,
  "Käyttäjän salasanojen asettaminen valvomatonta asennusta varten edellyttää virtuaalikoneen käynnistämistä sen luomisen yhteydessä"
 ],
 "Shell script": [
  null,
  "Komentotulkin komentosarja"
 ],
 "Shift+Insert": [
  null,
  "Vaihto + Syöttö"
 ],
 "Show additional options": [
  null,
  "Näytä lisävaihtoehdot"
 ],
 "Shut down": [
  null,
  "Sammuta"
 ],
 "Shut off": [
  null,
  "Sammuta"
 ],
 "Shut off the VM in order to edit firmware configuration": [
  null,
  "Sammuta virtuaalikone, jotta voit muokata laiteohjelmiston kokoonpanoa"
 ],
 "Shutting down": [
  null,
  "Sammutetaan"
 ],
 "Single rank": [
  null,
  "Yksi sijoitus"
 ],
 "Size": [
  null,
  "Koko"
 ],
 "Snapshot failed to be created": [
  null,
  "Tilannevedoksen luominen epäonnistui"
 ],
 "Snapshots": [
  null,
  "Tilannevedokset"
 ],
 "Sockets": [
  null,
  "Pistokkeet"
 ],
 "Source": [
  null,
  "Lähde"
 ],
 "Source format": [
  null,
  "Lähteen muoto"
 ],
 "Source path": [
  null,
  "Lähteen polku"
 ],
 "Source path should not be empty": [
  null,
  "Lähdepolku ei saa olla tyhjä"
 ],
 "Source should start with http, ftp or nfs protocol": [
  null,
  "Lähteen tulisi alkaa http-, ftp- tai nfs-protokollalla"
 ],
 "Source volume group": [
  null,
  "Lähteen taltioryhmä"
 ],
 "Space-saving computer": [
  null,
  "Tilaa säästävä tietokone"
 ],
 "Specific time": [
  null,
  "Tietty aika"
 ],
 "Start": [
  null,
  "Käynnistä"
 ],
 "Start libvirt": [
  null,
  "Käynnistä libvirt"
 ],
 "Start pool when host boots": [
  null,
  "Käynnistä varanto, kun isäntä käynnistyy"
 ],
 "Start should not be empty": [
  null,
  "Käynnistys ei tulisi olla tyhjä"
 ],
 "Startup": [
  null,
  "Aloittaa"
 ],
 "State": [
  null,
  "Tila"
 ],
 "Stick PC": [
  null,
  "Tikku-PC"
 ],
 "Storage": [
  null,
  "Tallennustila"
 ],
 "Storage pool $0 failed to get activated": [
  null,
  "Tallennusvarannon $0 aktivointi epäonnistui"
 ],
 "Storage pool $0 failed to get deactivated": [
  null,
  "Tallennusvarannon $0 aktivoinnin poisto epäonnistui"
 ],
 "Storage pool failed to be created": [
  null,
  "Varastointivarannon luominen epäonnistui"
 ],
 "Storage pool name": [
  null,
  "Varastointivarannon nimi"
 ],
 "Storage pools": [
  null,
  "Tallennustilavarannot"
 ],
 "Storage size must not be 0": [
  null,
  "Tallennuskoko ei saa olla 0"
 ],
 "Storage volume": [
  null,
  "Varastointivarannon taltio"
 ],
 "Storage volume size must not exceed the storage pool's capacity ($0 $1)": [
  null,
  "Tallennustaltion koko ei saa ylittää tallennusvarannon kapasiteettia ($0 $1)"
 ],
 "Storage volumes": [
  null,
  "Varastoinnin taltiot"
 ],
 "Storage volumes could not be deleted": [
  null,
  "Varastointitaltioita ei voitu poistaa"
 ],
 "Sub-Chassis": [
  null,
  "Alirunko"
 ],
 "Sub-Notebook": [
  null,
  "Ali -kannettava tietokone"
 ],
 "Suspended (PM)": [
  null,
  "Pysäytetty (PM)"
 ],
 "Synchronized": [
  null,
  "Synkronoitu"
 ],
 "Synchronized with $0": [
  null,
  "Synkronoi $0:n kanssa"
 ],
 "Synchronizing": [
  null,
  "Synkronoidaan"
 ],
 "System": [
  null,
  "Järjestelmä"
 ],
 "Tablet": [
  null,
  "Piirtopöytä"
 ],
 "Target": [
  null,
  "Kohde"
 ],
 "Target path": [
  null,
  "Kohteen polku"
 ],
 "Target path should not be empty": [
  null,
  "Kohdepolku ei saa olla tyhjä"
 ],
 "The $0 could not be deleted": [
  null,
  "$0:ta ei voitu poistaa"
 ],
 "The VM is running and will be forced off before deletion.": [
  null,
  "Virtuaalikone on käynnissä ja se pakotetaan pois päältä ennen poistamista."
 ],
 "The VM needs to be running or shut off to detach this device": [
  null,
  "Virtuaalikoneen on oltava käynnissä tai sammutettuna laitteen irrottamiseksi"
 ],
 "The directory on the server being exported": [
  null,
  "Viedyn palvelimen hakemisto"
 ],
 "The logged in user is not permitted to view system modifications": [
  null,
  "Sisäänkirjautunut käyttäjä ei saa tarkastella järjestelmän muutoksia"
 ],
 "The passwords do not match.": [
  null,
  "Salasanat eivät täsmää."
 ],
 "The pool is empty": [
  null,
  "Varanto on tyhjä"
 ],
 "The selected operating system does not support unattended installation": [
  null,
  "Valittu käyttöjärjestelmä ei tue valvomatonta asennusta"
 ],
 "The selected operating system has minimum memory requirement of $0 $1": [
  null,
  "Valitulla käyttöjärjestelmällä on vähimmäismäärä muistia $0 $1"
 ],
 "The selected operating system has minimum storage size requirement of $0 $1": [
  null,
  "Valitun käyttöjärjestelmän tallennustilan vähimmäisvaatimus on $0 $1"
 ],
 "The storage pool could not be deleted": [
  null,
  "Tallennusvarantoa ei voitu poistaa"
 ],
 "This VM is transient. Shut it down if you wish to delete it.": [
  null,
  "Tämä virtuaalikone on ohimenevä. Sammuta se, jos haluat poistaa sen."
 ],
 "This volume is already used by another VM.": [
  null,
  "Tätä taltiota käyttää jo toinen virtuaalikone."
 ],
 "This volume is already used by: ": [
  null,
  "Tätä taltiota käyttää jo: "
 ],
 "Threads per core": [
  null,
  "Säikeitä per ydin"
 ],
 "Time zone": [
  null,
  "Aikavyöhyke"
 ],
 "Today": [
  null,
  "Tänään"
 ],
 "Total size: $0": [
  null,
  "Koko yhteensä: $0"
 ],
 "Tower": [
  null,
  "Torni"
 ],
 "Transient VMs don't support editing firmware configuration": [
  null,
  "Ohimenevät virtuaalikoneet eivät tue laiteohjelmiston kokoonpanon muokkaamista"
 ],
 "Troubleshoot": [
  null,
  "Vianetsintä"
 ],
 "Trying to synchronize with $0": [
  null,
  "Yritetään synkronoida $0:n kanssa"
 ],
 "Type": [
  null,
  "Tyyppi"
 ],
 "Type ID": [
  null,
  "Tyypin tunnus"
 ],
 "URL (ISO image or distro install tree)": [
  null,
  "URL (ISO-kuvan tai jakelun asennuspuu)"
 ],
 "Unique name": [
  null,
  "Ainutlaatuinen nimi"
 ],
 "Unique network name": [
  null,
  "Ainutlaatuinen verkon nimi"
 ],
 "Unit": [
  null,
  "Yksikkö"
 ],
 "Unknown": [
  null,
  "Tuntematon"
 ],
 "Unknown firmware": [
  null,
  "Tuntematon laiteohjelmisto"
 ],
 "Unplug": [
  null,
  "Kytke pois"
 ],
 "Up to $0 $1 available on the default location": [
  null,
  "Jopa $0 $1 käytettävissä oletussijainnissa"
 ],
 "Up to $0 $1 available on the host": [
  null,
  "Jopa $0 $1 käytettävissä isännässä"
 ],
 "Url": [
  null,
  "Url"
 ],
 "Usage": [
  null,
  "Käyttö"
 ],
 "Use existing": [
  null,
  "Käytä olemassaolevaa"
 ],
 "Used": [
  null,
  "Käytetty"
 ],
 "Used by": [
  null,
  "Käyttävä"
 ],
 "User login": [
  null,
  "Käyttäjän sisäänkirjautuminen"
 ],
 "User login must not be empty when user password is set": [
  null,
  "Käyttäjän sisäänkirjautuminen ei saa olla tyhjä, kun käyttäjän salasana on asetettu"
 ],
 "User password": [
  null,
  "Käyttäjäsalasana"
 ],
 "User password must not be empty when user login is set": [
  null,
  "Käyttäjän salasana ei saa olla tyhjä, kun käyttäjän sisäänkirjautuminen on asetettu"
 ],
 "VCPU settings could not be saved": [
  null,
  "VCPU:n asetuksia ei voitu tallentaa"
 ],
 "VM $0 already exists": [
  null,
  "Virtuaalikone $0 on jo olemassa"
 ],
 "VM $0 does not exist on $1 connection": [
  null,
  "Virtuaalikone $0 ei ole olemassa yhteydellä $1"
 ],
 "VM $0 failed to force reboot": [
  null,
  "Virtuaalikoneen $0 uudelleenkäynnistyksen pakottaminen epäonnistui"
 ],
 "VM $0 failed to force shutdown": [
  null,
  "Virtuaalikone $0 epäonnistui pakottamaan sammutus"
 ],
 "VM $0 failed to get deleted": [
  null,
  "Virtuaalikone $0 epäonnistui saamaan itse poistetuksi"
 ],
 "VM $0 failed to get installed": [
  null,
  "Virtuaalikone $0 epäonnistui saamaan itse asennetuksi"
 ],
 "VM $0 failed to pause": [
  null,
  "Virtuaalikone $0 epäonnistui keskeytymään"
 ],
 "VM $0 failed to reboot": [
  null,
  "Virtuaalikone $0 epäonnistui käynnistymään uudelleen"
 ],
 "VM $0 failed to resume": [
  null,
  "Virtuaalikone $0 epäonnistui palautumaan"
 ],
 "VM $0 failed to send NMI": [
  null,
  "Virtuaalikone $0 epäonnistui lähettämään NMI"
 ],
 "VM $0 failed to shutdown": [
  null,
  "Virtuaalikone $0 epäonnistui sammuttamaan"
 ],
 "VM $0 failed to start": [
  null,
  "Virtuaalikone $0 epäonnistui käynnistymään"
 ],
 "VM state": [
  null,
  "Virtuaalikoneen tila"
 ],
 "VNC TLS port": [
  null,
  "VNC-TLS -portti"
 ],
 "VNC address": [
  null,
  "VNC-osoite"
 ],
 "VNC console": [
  null,
  "VNC-konsoli"
 ],
 "VNC port": [
  null,
  "VNC-portti"
 ],
 "Vendor": [
  null,
  "Toimittaja"
 ],
 "View automation script": [
  null,
  "Näytä automaatio-komentosarja"
 ],
 "Virtual Machines": [
  null,
  "Virtuaalikoneet"
 ],
 "Virtual machines": [
  null,
  "Virtuaalikoneet"
 ],
 "Virtual machines management": [
  null,
  "Virtuaalikoneiden hallinta"
 ],
 "Virtual network": [
  null,
  "Virtuaaliverkko"
 ],
 "Virtual network failed to be created": [
  null,
  "Virtuaaliverkon luominen epäonnistui"
 ],
 "Virtualization service (libvirt) is not active": [
  null,
  "Virtualisointipalvelu (libvirt) ei ole aktiivinen"
 ],
 "Volume": [
  null,
  "Taltio"
 ],
 "Volume failed to be created": [
  null,
  "Taltion luominen epäonnnistui"
 ],
 "Volume group name": [
  null,
  "Taltioryhmän nimi"
 ],
 "Volume group name should not be empty": [
  null,
  "Taltioryhmän nimi ei tulisi olla tyhjä"
 ],
 "WWPN": [
  null,
  "WWPN"
 ],
 "Waiting for other software management operations to finish": [
  null,
  "Odotetaan muiden ohjelmistojen hallintatoimintojen päättymistä"
 ],
 "Writeable": [
  null,
  "Kirjoitettava"
 ],
 "Writeable and shared": [
  null,
  "Kirjoitettava ja jaettu"
 ],
 "Yesterday": [
  null,
  "Eilen"
 ],
 "You need to select the most closely matching operating system": [
  null,
  "Sinun on valittava parhaiten vastaava käyttöjärjestelmä"
 ],
 "[$0 bytes of binary data]": [
  null,
  "[$0 tavua binääridatasta]"
 ],
 "[binary data]": [
  null,
  "[binääridata]"
 ],
 "[no data]": [
  null,
  "[ei dataa]"
 ],
 "active": [
  null,
  "aktiivinen"
 ],
 "bridge": [
  null,
  "silta"
 ],
 "cdrom": [
  null,
  "cd-rom"
 ],
 "custom": [
  null,
  "mukautettu"
 ],
 "direct": [
  null,
  "suora"
 ],
 "disabled": [
  null,
  "pois käytöstä"
 ],
 "disk": [
  null,
  "levy"
 ],
 "down": [
  null,
  "alas"
 ],
 "edit": [
  null,
  "muokkaa"
 ],
 "enabled": [
  null,
  "käytössä"
 ],
 "ethernet": [
  null,
  "ethernet"
 ],
 "host": [
  null,
  "isäntä"
 ],
 "host device": [
  null,
  "isäntälaite"
 ],
 "host passthrough": [
  null,
  "isännän läpivienti"
 ],
 "hostdev": [
  null,
  "isäntälaite"
 ],
 "iSCSI direct target": [
  null,
  "iSCSI -suora kohde"
 ],
 "iSCSI initiator IQN": [
  null,
  "iSCSI-aloittaja IQN"
 ],
 "iSCSI target": [
  null,
  "iSCSI-kohde"
 ],
 "iSCSI target IQN": [
  null,
  "iSCSI-kohteen IQN"
 ],
 "iso": [
  null,
  "iso"
 ],
 "libvirt": [
  null,
  "libvirt"
 ],
 "mcast": [
  null,
  "monilähetys"
 ],
 "network": [
  null,
  "verkko"
 ],
 "no": [
  null,
  "ei"
 ],
 "no state saved": [
  null,
  "ei tilaa tallennettuna"
 ],
 "password quality": [
  null,
  "salasanan laatu"
 ],
 "pxe": [
  null,
  "pxe"
 ],
 "qcow2": [
  null,
  "qcow2"
 ],
 "qemu": [
  null,
  "qemu"
 ],
 "redirected device": [
  null,
  "uudelleenohjattu laite"
 ],
 "server": [
  null,
  "palvelin"
 ],
 "show less": [
  null,
  "näytä vähemmän"
 ],
 "show more": [
  null,
  "näytä enemmän"
 ],
 "udp": [
  null,
  "udp"
 ],
 "up": [
  null,
  "ylös"
 ],
 "user": [
  null,
  "käyttäjä"
 ],
 "vCPU count": [
  null,
  "vCPU-lasku"
 ],
 "vCPU maximum": [
  null,
  "vCPU enintään"
 ],
 "vCPUs": [
  null,
  "vCPU:t"
 ],
 "vhostuser": [
  null,
  "virtuaali-isännän käyttäjä"
 ],
 "view more...": [
  null,
  "Katso lisää..."
 ],
 "virt-install package needs to be installed on the system in order to clone VMs": [
  null,
  "Paketti virt-install on asennettava järjestelmään virtuaalikoneiden kloonaamiseksi"
 ],
 "virt-install package needs to be installed on the system in order to create new VMs": [
  null,
  "Paketti virt-install on asennettava järjestelmään uusien virtuaalikoneiden luomiseksi"
 ],
 "virt-install package needs to be installed on the system in order to edit this attribute": [
  null,
  "Paketti virt-install on asennettava järjestelmään tämän attribuutin muokkaamiseksi"
 ],
 "vm": [
  null,
  "vm"
 ],
 "yes": [
  null,
  "kyllä"
 ]
});
